.. :changelog:

History
-------

0.1.0 (2019-07-26)
++++++++++++++++++

* First release on PyPI.


0.2.2 (2019-07-29)
++++++++++++++++++

* Bug fixes
* Documentation improvements


0.2.3 (2019-08-02)
++++++++++++++++++

* Use Pipenv for dependency management
* Configure Dependabot for automatic dependency upgrades
* Remove support for Python 3.4
* Documentation improvements


0.4.2 (2019-08-16)
++++++++++++++++++

* Switch to the new official Elastic App Search python client
* Documentation improvements
